#define XERR
#include "mammo.ih"

void Mammo::betaHandler()
{
    d_base.back() = "beta:";

    Parser::extract( Parser::one(d_base), d_beta, N_BETA);
}



